# rBat
Repo for the rBat package — behavioural quantification algorithms &amp; preprocessing methods.

----
## Important Links

- Source Code: https://github.com/brandonc-edu/rBat
- Bug Reports: https://github.com/brandonc-edu/rBat/issues

## Capabilities

It provides:
- Objects to replicate test environments for purposes of tracking rat movement.
- Functions to calculate summary measures — quantifications of the rat's OCD-like behaviour.
- Preprocessing methods to smooth time-spatial data and segment it into episodes of movement types (lingering, progression, etc.)
- API Interfaces to assist in preprocessing and summary measure calcuations.

## Testing

rBat requires `pytest` to test the summary measure and preprocessing algorithms.

----
## Credits

Brandon Carrasco & Daniel Locke - Original Developers of rBat Package
Inoday Yadav & Jamie Wong - Tested rBat package functionality
Dr. Henry Szechtman & Dr. Anna Dvorkin-Gheva - Supervisors & Consultants for Desired Functionality

### Implementations Based Upon

#### Summary Measures

Szechtman, H., Sulis, W., & Eilam, D. (1998). Quinpirole induces compulsive checking behavior in rats: a potential animal model of obsessive-compulsive disorder (OCD). Behavioral neuroscience, 112(6), 1475–1485. https://doi.org/10.1037//0735-7044.112.6.1475

Dvorkin, A., Perreault, M. L., & Szechtman, H. (2006). Development and temporal organization of compulsive checking induced by repeated injections of the dopamine agonist quinpirole in an animal model of obsessive-compulsive disorder. Behavioural brain research, 169(2), 303–311. https://doi.org/10.1016/j.bbr.2006.01.024

Dvorkin, A., Culver, K. E., & Szechtman, H. (2006). Differential effects of clorgyline on sensitization to quinpirole in rats tested in small and large environments. Psychopharmacology, 186(4), 534–543. https://doi.org/10.1007/s00213-006-0377-4

Tucci, M. C., Dvorkin-Gheva, A., Johnson, E., Cheon, P., Taji, L., Agarwal, A., Foster, J., & Szechtman, H. (2014). Performance of compulsive behavior in rats is not a unitary phenomenon - validation of separate functional components in compulsive checking behavior. The European journal of neuroscience, 40(6), 2971–2979. https://doi.org/10.1111/ejn.12652

#### Preprocessing

Hen, I., Sakov, A., Kafkafi, N., Golani, I., & Benjamini, Y. (2004). The dynamics of spatial behavior: how can robust smoothing techniques help?. Journal of neuroscience methods, 133(1-2), 161–172. https://doi.org/10.1016/j.jneumeth.2003.10.013

Drai, D., Benjamini, Y., & Golani, I. (2000). Statistical discrimination of natural modes of motion in rat exploratory behavior. Journal of neuroscience methods, 96(2), 119–131. https://doi.org/10.1016/s0165-0270(99)00194-6

Additional implementation details gleaned from: https://www.tau.ac.il/~ilan99/see/help/
